﻿
using System;
using System.Windows;
using System.Windows.Media;

using MindFusion.Scheduling;
using MindFusion.Scheduling.Wpf;


namespace WpfApplication46
{
	public class CustomCellPresenter : CellPresenter
	{
		static CustomCellPresenter()
		{
			DefaultStyleKeyProperty.OverrideMetadata(typeof(CustomCellPresenter),
				new FrameworkPropertyMetadata(typeof(CustomCellPresenter)));
			IsSelectedProperty.OverrideMetadata(typeof(CustomCellPresenter),
				new PropertyMetadata(OnIsSelectedChanged));
		}

		public CustomCellPresenter(Calendar calendar)
			: base(calendar)
		{
			calendar.ItemModified += (s, e) => UpdateBackground();
			calendar.ItemCreated += (s, e) => UpdateBackground();
			calendar.ItemDeleted += (s, e) => UpdateBackground();
			UpdateBackground();
		}

		protected override void OnStartTimeChanged(DateTime oldTime, DateTime newTime)
		{
			base.OnStartTimeChanged(oldTime, newTime);

			UpdateBackground();
		}

		protected override void OnEndTimeChanged(DateTime oldTime, DateTime newTime)
		{
			base.OnEndTimeChanged(oldTime, newTime);

			UpdateBackground();
		}

		private void UpdateBackground()
		{
			if (StartTime == DateTime.MinValue || EndTime == DateTime.MinValue)
				return;

			var items = Calendar.Schedule.GetAllItems(StartTime, EndTime.AddTicks(-1));
			if (items.Count == 0)
			{
				ClearValue(CustomBackgroundProperty);
			}
			else
			{
				if (items[0].RecurrenceState != RecurrenceState.None)
					CustomBackground = Brushes.Red;
				else
					CustomBackground = Brushes.Green;
			}
		}

		private static void OnIsSelectedChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
		{
			((CustomCellPresenter)d).UpdateBackground();
		}


		public Brush CustomBackground
		{
			get { return (Brush)GetValue(CustomBackgroundProperty); }
			set { SetValue(CustomBackgroundProperty, value); }
		}

		public static readonly DependencyProperty CustomBackgroundProperty =
			DependencyProperty.Register("CustomBackground", typeof(Brush), typeof(CustomCellPresenter),
			new PropertyMetadata(new SolidColorBrush(Color.FromArgb(255, 235, 235, 235))));
	}
}
